************************************************************************
*                                                                      *
      SUBROUTINE DSDA(PNRG,ATARG,ANGLE,SIGS,DSIGS,ESCAT,ETARG)
*                                                                      *
*     COMPUTE ELASTIC SCATTERING CROSS-SECTION USING                   *
*     FRAUNHOFFER DIFFRACTION (B)                                      *
*     FOR SCATTERING FORMULAE, SEE S. PEARLSTEIN, NUC. SCI. ENG.       *
*     49,162-171(1972)                                                 *
*                                                                      *
*     INPUT:                                                           *
*       PNRG=K.E. OF INCIDENT NUCLEON IN LAB (MEV)                     *
*       ATARG=TARGET MASS (AMU)                                        *
*       ANGLE=LAB SCATTERING ANGLE (DEG)                               *
*       SIGS=ELASTIC SCATTERING CROSS-SECTION (B)                      *
*     OUTPUT:                                                          *
*       DSIGS=DIFFERENTIAL ELASTIC CROSS-SECTION (B/SR)                *
*       ESCAT=LAB K.E. OF SCATTERED NUCLEON (MEV)                      *
*       ETARG=PNRG-ESCAT=LAB K.E. OF SCATTERED TARGET (MEV)            *
*                                                                      *
*     ALREADY SETUP FOR LAB INPUT AND LAB OUTPUT. IF ZLM INPUT AND ZLM *
*     OUTPUT WANTED, SET LCT=2.                                        *
*                                                                      *
************************************************************************
*
      COMMON /INCP/   INCP
      COMMON /RZ/     RZ
      COMMON /LCT/    LCT
*
      DOUBLEPRECISION QQQQQQ
*
*-----------------------------------------------------------------------
*
      LCT=1
      PI=3.1415927
      CALL SYSCON(PNRG,ATARG,ANGLE,VK,ANGZLM,ESCAT,CONV)
*
*   FOR DSDA IN ZLM SYSTEM, LCT=2
*
      IF(LCT.EQ.1) GO TO 10
      ANGZLM=ANGLE
      CONV=1.
   10 CONTINUE
      A=ATARG
      IF(RZ.EQ.0.) RZ=0.14
      ADD=1.
      IF(INCP.EQ.10020) ADD=2.
      FACT=1.
      IF(INCP.EQ.10020) FACT=SQRT(2.)
      R=(RZ*A**0.3333+0.122*FACT*(A+ADD)/A)*1.E-12
 9020 FORMAT(1X,I10,8E13.5)
      R2SQ=(VK*R*R)**2*1.E+24
      DELTA=2.E-13
      AREA=PI*R*R*1.0E+24
      VKR2=2.*VK*R
      SIGASM=AREA*(1.-2./(PI*VKR2))
      CALL BESSEL(0,VKR2,BESZ)
      CALL BESSEL(1,VKR2,BES1)
      SIG=AREA*(1.-BESZ**2-BES1**2)
      IF(PNRG.LT.20.) SIGS=SIG
      IF(INCP.NE.10010.OR.INCP.NE.10) SIGS=SIG
      DNORM=SIGS/SIG
      QQQQQQ=ANGZLM
      U=DCOS(QQQQQQ)
      S=SQRT((1.0-U)/2.0)
      IF(U.EQ.1.0) S=0.
      XAV=2.*VK*R*S
      IF(XAV.GT.1.E-2) GO TO 25
   20 XJ1X=0.5
      Y1=XJ1X*XJ1X
      GO TO 30
   25 CONTINUE
      DEL=0.05*R
      XPL=2.*VK*(R+DEL)*S
      XMI=2.*VK*(R-DEL)*S
      CALL BESSEL(1,XPL,XJ1PL)
      CALL BESSEL(1,XMI,XJ1MI)
      Y1=0.5*((XJ1PL/XPL)**2+(XJ1MI/XMI)**2)
C     FOLLOWING FITS HUTCHEON PRL 47,315(81) DATA 200-400 MEV P+PB DATA
      CF1=0.2*(208./A)**0.3333
      Y1=Y1*EXP(-CF1*XAV-CF1/40.*XAV**2)
   30 DSIGS=R2SQ*Y1
 9010 FORMAT(1X,10E12.4)
      DSIGS=DSIGS*DNORM*CONV
      IF(ABS(DSIGS).LE.1.E-12) DSIGS=0.
      ETARG=PNRG-ESCAT
*
      RETURN
      END
