************************************************************************
*                                                                      *
      SUBROUTINE SIG(PNRG,ATARG,SIGT,SIGR,SIGS)
*                                                                      *
*     CALCULATES TOTAL, NONELASTIC AND SCATTERING CROSS-SECTIONS       *
*     ABOVE 20 MEV FOR INCIDENT NUCLEONS.  CODE SET FOR PROTONS BUT    *
*     CAN BE CHANGED TO INCIDENT NEUTRONS.                             *
*     INPUT:                                                           *
*       PNRG=INCIDENT NUCLEON ENERGY (MEV)                             *
*      ATARG=TARGET MASS (AMU)                                         *
*     OUTPUT:                                                          *
*       SIGT=TOTAL CROSS-SECTION (B)                                   *
*       SIGR=NONELASTIC CROSS-SECTION (B)                              *
*       SIGS=SIGT-SIGR=ELASTIC SCATTERING CROSS-SECTION (B)            *
*                                                                      *
************************************************************************
*
      COMMON /INCP/   INCP
      COMMON /RZ/     RZ
*
      DIMENSION       PAR(4),C(4,3)
*
      DATA (C(1,K),K=1,3)/1.353,0.4993,1.076/
      DATA (C(2,K),K=1,3)/0.6653,0.9900,1.040/
      DATA (C(3,K),K=1,3)/2.456,2.060,0.9314/
      DATA (C(4,K),K=1,3)/0.1167,1.623,0.9736/
*
*-----------------------------------------------------------------------
*
      IF(RZ.EQ.0.) RZ=0.14
      A=ATARG
      EMEV=PNRG
*
*     NUCLEAR RADIUS (CM.)
*
      R=(RZ*A**0.3333+0.122*(A+1.)/A)*1.E-12
*
*     CALCULATION OF SIGR AS J.LETAW ETAL., ASTROPHYS. J. SUPP. SERIES
*     51,271-276(1983).
*     SIGRB=ASYMPTOTIC HIGH ENERGY REACTION CROSS-SECTION
*
      SIGRB=0.045*A**0.7
*
*     ENERGY DEPENDENT FACTOR
*
      F1=1.-0.62*EXP(-EMEV/200.)*SIN(10.9/EMEV**0.28)
*
*     PEARLSTEIN ADDED LOW ENERGY ENHANCEMENT FACTOR OF 10%
*
      F1=F1*(1.+0.1*EXP(-(EMEV-20.)/10.))
*
*     MASS DEPENDENT FACTOR
*
      F2=1.+0.016*SIN(5.3-2.63*ALOG(A))
      SIGR=SIGRB*F1*F2
*
*     SIGT ACCORDING TO FIT BY S. PEARLSTEIN, JUNE 86.
*
      A13=A**0.3333
      A23=A**0.6667
      ALG=ALOG(A)
      DO 210 K=1,4
      PAR(K)=ALOG(C(K,1))+ALOG(C(K,2))*ALG+ALOG(C(K,3))*ALG**2
      PAR(K)=EXP(PAR(K))
  210 CONTINUE
      EPK=PAR(3)*A13
      FEXP1=PAR(2)*ALOG(EPK/EMEV)
      SIGT=SIGR*(1.+PAR(4))+PAR(1)*A13*EXP(-FEXP1**2)
      IF(EMEV.LT.20.) GO TO 220
      ECST=82.0
      ACST=238.
      ESUB=ECST*A13/ACST**0.3333
      EPK2=EPK-ESUB
      IF(EPK2.LE.0.) GO TO 220
      FEXP2=PAR(2)*ALOG(EPK2/EMEV)
      SIGT=SIGT+PAR(1)*A13*EXP(-FEXP2**2)
  220 CONTINUE
*
*     FOR INCIDENT NEUTRONS, GO TO 250
*
      AP=1.
      IF(INCP.EQ.10020) AP=2.
      IF(EMEV.LT.20.) CALL RAMS(EMEV,A,AP,SIGT,SIGR)
      IF(INCP.EQ.10) GO TO 250
      IF(EMEV.GE.50.) GO TO 250
*
*     COULOMB FACTOR
*     Z FOR STABLE NUCLEUS ACCORDING TO A, AS D. HALLIDAY, INTRO.
*     NUCLEAR PHYSICS, WILEY P.296
*
      Z=66.7*A/(A23+132.)
*
*     EC, COULOMB BARRIER HALF-HEIGHT, SIMILAR TO S. PEARLSTEIN,
*     J. NUC. ENERGY 23,87(1975) USING OPTICAL MODEL INVERSE P CS'S.
*
      W=5.
      EC=2.+0.19*Z
      FEXCB=EXP((EC-EMEV)/W)
      FCOUL=1./(1.+FEXCB)*(1.-EXP(-EMEV/W))
      SIGT=SIGT*FCOUL
      SIGR=SIGR*FCOUL
  250 SIGS=SIGT-SIGR
*
      RETURN
      END
